<?php


namespace Schaffen\Core\Product\Repositories;

use Freelabois\LaravelQuickstart\Extendables\Repository;
use Schaffen\Core\Product\Models\ProductVarietyPack;

class ProductVarietyPackRepository extends Repository
{
    protected $model = ProductVarietyPack::class;

    protected $searchableFields = [
        ["field" => 'pes_status'],
        ["field" => 'pve_codigo']
    ];

    public function injectFiltersOnQuery()
    {
        $serial = NULL;
        $precisa_de_usuario = NULL;
        $only_service = NULL;
        $only_active = NULL;
        $product_complete_name = NULL;
        $composition = NULL;

        extract($this->filters);

        $this->query->when($serial, function ($query) use ($serial) {
            return $query->whereHas('employee.mobile', function ($query) use ($serial) {
                return $query->where('fum_serial', $serial)
                    ->whereNull('fum_bloqueado')
                    ->where('fum_libera_manutencao', 1);
            });
        });

        $this->query->when($precisa_de_usuario, function ($query) {
            return $query->whereHas('users');
        });

        $this->query->when($only_service, function ($query) use ($only_service) {
            return $query->whereHas('product_variety.product', function ($query) use ($only_service) {
                if (is_bool($only_service) ? $only_service : $only_service == "true") {
                    $query->where("pro_servico", 1);
                }
                return $query;
            });
        });

        $this->query->when($only_active, function ($query) use ($only_active) {
            return $query->whereHas('product_variety.product', function ($query) use ($only_active) {
                if (is_bool($only_active) ? $only_active : $only_active == "true") {
                    $query->where("pro_status", 1);
                }
                return $query;
            });
        });


        //commit
        $this->query->when($product_complete_name, function ($query) use ($product_complete_name) {
            $field = "pro_descricao||' - '||prv_descricao||' - '||unm_descricao";
            $field .= " || case when trim(pve_codigo_barras) <> '' then ' - ('||pve_codigo_barras||')' else '' end";
            $field .= " || case when mar_codigo <> '-1' then' - '||mar_descricao||'' else '' end";
            return $query->whereRaw("{$field} ilike '%{$product_complete_name}%' ");
        });

        $this->query->when($composition, function ($query) {
            return $query->whereHas('composition');
        });

        parent::injectFiltersOnQuery();
    }
}
